@@ -1,7 +1,7 @@
 
 /*
  *  autogen.h
- *  $Id: autogen.h,v 4.8 2005/09/10 18:37:50 bkorb Exp $
+ *  $Id: autogen.h,v 4.11 2005/12/05 20:51:36 bkorb Exp $
  *  Global header file for AutoGen
  */
 
@@ -56,6 +56,8 @@
 
 #define YYSTYPE t_word
 
+#define ag_offsetof(TYPE, MEMBER) ((unsigned long) &((TYPE *)0)->MEMBER)
+
 /*
  *  Dual pipe opening of a child process
  */
@@ -125,6 +127,9 @@ typedef struct template_lib_marker tTlibMark;
 typedef tMacro* (tLoadProc)( tTemplate*, tMacro*, const char** ppzScan );
 typedef tLoadProc* tpLoadProc;
 
+typedef void (tUnloadProc)( tMacro* );
+typedef tUnloadProc* tpUnloadProc;
+
 /*
  *  Procedure for handling a template function
  *  during the text emission phase.
@@ -373,6 +378,7 @@ MODE int         endMacLen        VALUE( 0  );
 MODE char        zEndMac[   8 ]   VALUE( "" );
 MODE int         startMacLen      VALUE( 0  );
 MODE char        zStartMac[  8 ]  VALUE( "" );
+MODE int         guileFailure     VALUE( 0 );
 
 /*
  *  Definition Parsing Globals
@@ -466,16 +472,109 @@ MODE v2c_t p2p VALUE( { NULL } );
 #define AG_ABEND_IN(t,m,s) \
     STMTS( pCurTemplate=(t); pCurMacro=(m); AG_ABEND(s);)
 
+extern void  ag_scmStrings_init(   void );
+extern void  ag_scmStrings_deinit( void );
+extern void  ag_scmStrings_free(   void );
+extern char* ag_scribble( size_t size );
+
+/*
+ *  Code variations based on the version of Guile:
+ */
+#if GUILE_VERSION < 106000
+
+# define AG_SCM_STRLEN(_s)       SCM_LENGTH(_s)
+# define AG_SCM_STRING_P(_s)     gh_string_p(_s)
+# define AG_SCM_BOOL_P(_b)       gh_boolean_p(_b)
+# define AG_SCM_SYM_P(_s)        gh_symbol_p(_s)
+# define AG_SCM_IS_PROC(_p)      gh_procedure_p(_p)
+# define AG_SCM_CHAR_P(_c)       gh_char_p(_c)
+# define AG_SCM_VEC_P(_v)        gh_vector_p(_v)
+# define AG_SCM_PAIR_P(_p)       gh_pair_p(_p)
+# define AG_SCM_NUM_P(_n)        gh_number_p(_n)
+# define AG_SCM_LIST_P(_l)       gh_list_p(_l)
+
+# define AG_SCM_MKSTR(_s, _ch)   MUST NOT USE
+
+# define AG_SCM_EVAL_STR(_s)     gh_eval_str(_s)
+# define AG_SCM_CHARS(_s)        SCM_CHARS(_s)
+# define AG_SCM_STR2SCM(_st,_sz) gh_str2scm(_st,_sz)
+# define AG_SCM_STR02SCM(_s)     gh_str02scm(_s)
+# define AG_SCM_INT2SCM(_i)      gh_int2scm(_i)
+# define AG_SCM_SCM2INT(_i)      gh_scm2int(_i)
+# define AG_SCM_LONG2SCM(_i)     gh_long2scm(_i)
+# define AG_SCM_SCM2LONG(_i)     gh_scm2long(_i)
+
 static inline char* ag_scm2zchars( SCM s, tCC* type )
 {
-    if (! gh_string_p( s ))
+    if (! AG_SCM_STRING_P( s ))
         AG_ABEND( aprf( zNotStr, type ));
 
     if (SCM_SUBSTRP(s))
-        s = scm_makfromstr( SCM_ROCHARS(s), SCM_ROLENGTH(s), 0 );
-    return SCM_CHARS(s);
+        s = scm_makfromstr( SCM_CHARS(s), SCM_LENGTH(s), 0 );
+    return SCM_CHARS(s);  /* pre-Guile 1.7.x */
 }
 
+#elif GUILE_VERSION < 107000
+
+# define AG_SCM_STRLEN(_s)       SCM_LENGTH(_s)
+# define AG_SCM_STRING_P(_s)     SCM_STRINGP(_s)
+# define AG_SCM_BOOL_P(_b)       SCM_BOOLP(_b)
+# define AG_SCM_SYM_P(_s)        SCM_SYMBOLP(_s)
+# define AG_SCM_IS_PROC(_p)      SCM_NFALSEP( scm_procedure_p(_p))
+# define AG_SCM_CHAR_P(_c)       SCM_CHARP(_c)
+# define AG_SCM_VEC_P(_v)        SCM_VECTORP(_v)
+# define AG_SCM_PAIR_P(_p)       SCM_NFALSEP( scm_pair_p(_p))
+# define AG_SCM_NUM_P(_n)        SCM_NUMBERP(_n)
+# define AG_SCM_LIST_P(_l)       SCM_NFALSEP( scm_list_p(_l))
+
+# define AG_SCM_MKSTR(_s, _ch)   MUST NOT USE
+
+# define AG_SCM_EVAL_STR(_s)     scm_c_eval_string(_s)
+# define AG_SCM_CHARS(_s)        SCM_CHARS(_s)
+# define AG_SCM_STR2SCM(_st,_sz) scm_mem2string(_st,_sz)
+# define AG_SCM_STR02SCM(_s)     scm_makfrom0str(_s)
+# define AG_SCM_INT2SCM(_i)      gh_int2scm(_i)
+# define AG_SCM_SCM2INT(_i)      gh_scm2int(_i)
+# define AG_SCM_LONG2SCM(_i)     gh_long2scm(_i)
+# define AG_SCM_SCM2LONG(_i)     gh_scm2long(_i)
+
+static inline char* ag_scm2zchars( SCM s, tCC* type )
+{
+    if (! AG_SCM_STRING_P( s ))
+        AG_ABEND( aprf( zNotStr, type ));
+
+    if (SCM_SUBSTRP(s))
+        s = scm_makfromstr( SCM_CHARS(s), SCM_LENGTH(s), 0 );
+    return SCM_CHARS(s);  /* pre-Guile 1.7.x */
+}
+
+
+#else
+  extern char* ag_scm2zchars( SCM s, tCC* type );
+
+# define AG_SCM_STRLEN(_s)       SCM_STRING_LENGTH(_s)
+# define AG_SCM_STRING_P(_s)     scm_is_string(_s)
+# define AG_SCM_BOOL_P(_b)       SCM_BOOLP(_b)
+# define AG_SCM_SYM_P(_s)        SCM_SYMBOLP(_s)
+# define AG_SCM_IS_PROC(_p)      scm_is_true( scm_procedure_p(_p))
+# define AG_SCM_CHAR_P(_c)       SCM_CHARP(_c)
+# define AG_SCM_VEC_P(_v)        SCM_VECTORP(_v)
+# define AG_SCM_PAIR_P(_p)       scm_is_true( scm_pair_p(_p))
+# define AG_SCM_NUM_P(_n)        SCM_NUMBERP(_n)
+# define AG_SCM_LIST_P(_l)       SCM_NFALSEP( scm_list_p(_l))
+
+# define AG_SCM_MKSTR(_s, _ch)   MUST NOT USE
+
+# define AG_SCM_EVAL_STR(_s)     scm_c_eval_string(_s)
+# define AG_SCM_CHARS(_s)        SCM_STRING_CHARS(_s)
+# define AG_SCM_STR2SCM(_st,_sz) scm_from_locale_stringn(_st,_sz)
+# define AG_SCM_STR02SCM(_s)     scm_from_locale_string(_s)
+# define AG_SCM_INT2SCM(_i)      gh_int2scm(_i)
+# define AG_SCM_SCM2INT(_i)      gh_scm2int(_i)
+# define AG_SCM_LONG2SCM(_i)     gh_long2scm(_i)
+# define AG_SCM_SCM2LONG(_i)     gh_scm2long(_i)
+#endif
+
 static inline SCM ag_eval( tCC* pzStr )
 {
     SCM res;
