@@ -1,12 +1,12 @@
 /*
- *  $Id: defLoad.c,v 1.28 2004/02/02 03:31:50 bkorb Exp $
+ *  $Id: defLoad.c,v 4.8 2005/12/04 22:26:21 bkorb Exp $
  *  This module loads the definitions, calls yyparse to decipher them,
  *  and then makes a fixup pass to point all children definitions to
  *  their parent definition.
  */
 
 /*
- *  AutoGen copyright 1992-2004 Bruce Korb
+ *  AutoGen copyright 1992-2005 Bruce Korb
  *
  *  AutoGen is free software.
  *  You may redistribute it and/or modify it under the terms of the
@@ -21,19 +21,25 @@
  *  You should have received a copy of the GNU General Public License
  *  along with AutoGen.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  */
 
-STATIC tDefEntry* pFreeEntryList = NULL;
-STATIC void*      pAllocList     = NULL;
+static tDefEntry* pFreeEntryList = NULL;
+static void*      pAllocList     = NULL;
 
 #define ENTRY_SPACE        (4096 - sizeof(void*))
 #define ENTRY_ALLOC_CT     (ENTRY_SPACE / sizeof(tDefEntry))
 #define ENTRY_ALLOC_SIZE   \
     ((ENTRY_ALLOC_CT * sizeof( tDefEntry )) + sizeof(void*))
 
-EXPORT void
+/* = = = START-STATIC-FORWARD = = = */
+/* static forward declarations maintained by :mkfwd */
+static tDefEntry*
+insertDef( tDefEntry* pDef );
+/* = = = END-STATIC-FORWARD = = = */
+
+LOCAL void
 freeEntry( tDefEntry* pDE )
 {
     pDE->pNext = pFreeEntryList;
@@ -41,7 +47,7 @@ freeEntry( tDefEntry* pDE )
 }
 
 
-EXPORT tDefEntry*
+LOCAL tDefEntry*
 getEntry( void )
 {
     tDefEntry*  pRes = pFreeEntryList;
@@ -88,7 +94,7 @@ getEntry( void )
 /*
  *  Append a new entry at the end of a sibling (or twin) list.
  */
-STATIC tDefEntry*
+static tDefEntry*
 insertDef( tDefEntry* pDef )
 {
     tDefEntry* pList = ppParseStack[ stackDepth ];
@@ -149,23 +155,28 @@ insertDef( tDefEntry* pDef )
          *  We actually do this by leaving the pList pointer alone and swapping
          *  the contents of the definition entry.
          */
-        uDefValue val = pDef->val;
-        long      idx = pDef->index;
+        tDefEntry def = *pDef;
 
-        pDef->index   = pList->index;
-        pList->index  = idx;
-        pDef->val     = pList->val;
-        pList->val    = val;
+        memcpy( &(pDef->pzDefName), &(pList->pzDefName),
+                sizeof( def ) - ag_offsetof(tDefEntry, pzDefName) );
+
+        memcpy( &(pList->pzDefName), &(def.pzDefName),
+                sizeof( def ) - ag_offsetof(tDefEntry, pzDefName) );
 
         /*
-         *  Link the pDef in between pList and pList->pTwin
+         *  Contents are swapped.  Link "pDef" after "pList" and return "pList".
          */
-        pDef->pTwin   = pList->pTwin;
+        pDef->pTwin = pList->pTwin;
         if (pDef->pTwin != NULL)
             pDef->pTwin->pPrevTwin = pDef;
 
         pDef->pPrevTwin = pList;
         pList->pTwin  = pDef;
+
+        /*
+         *  IF this is the first twin, then the original list head is now
+         *  the "end twin".
+         */
         if (pList->pEndTwin == NULL)
             pList->pEndTwin = pDef;
 
@@ -198,7 +209,7 @@ insertDef( tDefEntry* pDef )
 }
 
 
-EXPORT tDefEntry*
+LOCAL tDefEntry*
 findPlace( char* name, tCC* pzIndex )
 {
     tDefEntry* pE = getEntry();
@@ -212,14 +223,16 @@ findPlace( char* name, tCC* pzIndex )
         pE->index = strtol( pzIndex, NULL, 0 );
 
     else {
-        pzIndex = getDefine( pzIndex );
+        pzIndex = getDefine( pzIndex, AG_TRUE );
         if (pzIndex != NULL)
              pE->index = strtol( pzIndex, NULL, 0 );
         else pE->index = NO_INDEX;
     }
 
     strtransform( pE->pzDefName, pE->pzDefName );
-    pE->valType   = VALTYP_UNKNOWN;
+    pE->valType     = VALTYP_UNKNOWN;
+    pE->pzSrcFile   = (char*)pCurCtx->pzCtxFname;
+    pE->srcLineNum  = pCurCtx->lineNo;
     return (pCurrentEntry = insertDef( pE ));
 }
 
@@ -228,7 +241,7 @@ findPlace( char* name, tCC* pzIndex )
  *
  *  Suck in the entire definitions file and parse it.
  */
-EXPORT void
+LOCAL void
 readDefines( void )
 {
     char*    pzData;
@@ -241,7 +254,7 @@ readDefines( void )
         pBaseCtx = (tScanCtx*)AGALOC( sizeof( tScanCtx ), "scan context" );
         memset( (void*)pBaseCtx, 0, sizeof( tScanCtx ));
         pBaseCtx->lineNo     = 1;
-        pBaseCtx->pzFileName = "@@ No-Definitions @@";
+        pBaseCtx->pzCtxFname = "@@ No-Definitions @@";
         return;
     }
 
@@ -252,7 +265,7 @@ readDefines( void )
      *  the stdin input exceeds our initial allocation of 16K.
      */
     if (strcmp( OPT_ARG( DEFINITIONS ), "-" ) == 0) {
-        OPT_ARG( DEFINITIONS )  = "stdin";
+        OPT_ARG( DEFINITIONS ) = "stdin";
         if (getenv( "REQUEST_METHOD" ) != NULL) {
             loadCgi();
             pCurCtx = pBaseCtx;
@@ -320,11 +333,14 @@ readDefines( void )
     /*
      *  Set the input file pointer, as needed
      */
-    fp = useStdin ? stdin
-                  : fopen( OPT_ARG( DEFINITIONS ), "r" FOPEN_TEXT_FLAG );
-    if (fp == NULL)
-        AG_ABEND( aprf( zCannot, errno, "open", OPT_ARG( DEFINITIONS ),
-                        strerror( errno )));
+    if (useStdin)
+        fp = stdin;
+    else {
+        fp = fopen( OPT_ARG( DEFINITIONS ), "r" FOPEN_TEXT_FLAG );
+        if (fp == NULL)
+            AG_ABEND( aprf( zCannot, errno, "open", OPT_ARG( DEFINITIONS ),
+                            strerror( errno )));
+    }
 
     /*
      *  Read until done...
@@ -392,13 +408,13 @@ readDefines( void )
         AG_ABEND( "No definition data were read" );
 
     *pzData = NUL;
-    AGDUPSTR( pBaseCtx->pzFileName, OPT_ARG( DEFINITIONS ), "def file name" );
+    AGDUPSTR( pBaseCtx->pzCtxFname, OPT_ARG( DEFINITIONS ), "def file name" );
 
     /*
      *  Close the input file, parse the data
      *  and alphabetically sort the definition tree contents.
      */
-    if (fp != stdin)
+    if (! useStdin)
         fclose( fp );
 
     pCurCtx = pBaseCtx;
@@ -406,7 +422,7 @@ readDefines( void )
 }
 
 
-extern void
+void
 unloadDefs( void )
 {
 }
