@@ -1,6 +1,6 @@
 
 /*
- *  $Id: expPrint.c,v 4.3 2005/01/24 00:00:32 bkorb Exp $
+ *  $Id: expPrint.c,v 4.7 2005/12/21 20:58:43 bkorb Exp $
  *
  *  The following code is necessary because the user can give us
  *  a printf format requiring a string pointer yet fail to provide
@@ -25,8 +25,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with AutoGen.  See the file "COPYING".  If not,
  *  write to:  The Free Software Foundation, Inc.,
- *             59 Temple Place - Suite 330,
- *             Boston,  MA  02111-1307, USA.
+ *             51 Franklin Street, Fifth Floor,
+ *             Boston, MA  02110-1301, USA.
  */
 
 static sigjmp_buf printJumpEnv;
@@ -168,7 +168,7 @@ run_printf( char* pzFmt, int len, SCM alist )
     {
         char*   pzBuf;
         ssize_t bfSize = safePrintf( &pzBuf, pzFmt, arglist );
-        res = gh_str2scm( pzBuf, bfSize );
+        res = AG_SCM_STR2SCM( pzBuf, bfSize );
         free( pzBuf );
     }
 
@@ -277,31 +277,24 @@ ag_scm_hide_email( SCM display, SCM eaddr )
     tSCC zFmt[]   = "&#%d;";
     char*  pzDisp = ag_scm2zchars( display, pzFormatName );
     char*  pzEadr = ag_scm2zchars( eaddr,   pzFormatName );
-    SCM    res;
-
-    {
-        size_t sz = (strlen( pzEadr ) * sizeof( zFmt ))
+    size_t str_size = (strlen( pzEadr ) * sizeof( zFmt ))
             + sizeof( zStrt ) + sizeof( zEnd ) + strlen( pzDisp );
 
-        res = scm_makstr( sz, 0 );
+    char*  pzRes  = ag_scribble( str_size );
+    char*  pzScan = pzRes;
+
+    strcpy( pzScan, zStrt );
+    pzScan += sizeof( zStrt ) - 1;
+
+    for (;;) {
+        if (*pzEadr == NUL)
+            break;
+        pzScan += sprintf( pzScan, zFmt, *(pzEadr++) );
     }
 
-    {
-        char* pz = SCM_CHARS( res );
+    pzScan += sprintf( pzScan, zEnd, pzDisp );
 
-        strcpy( pz, zStrt );
-        pz += sizeof( zStrt ) - 1;
-
-        for (;;) {
-            if (*pzEadr == NUL)
-                break;
-            pz += sprintf( pz, zFmt, *(pzEadr++) );
-        }
-
-        sprintf( pz, zEnd, pzDisp );
-    }
-
-    return res;
+    return AG_SCM_STR2SCM( pzRes, pzScan - pzRes );
 }
 
 
@@ -347,7 +340,7 @@ ag_scm_format_arg_count( SCM fmt )
         }
     } scanDone:;
 
-    return gh_int2scm( ct );
+    return AG_SCM_INT2SCM( ct );
 }
 /*
  * Local Variables:
