@@ -1,6 +1,6 @@
 
 /*
- *  $Id: funcDef.c,v 4.4 2005/06/07 22:26:43 bkorb Exp $
+ *  $Id: funcDef.c,v 4.5 2005/12/04 22:26:21 bkorb Exp $
  *
  *  This module implements the DEFINE text function.
  */
@@ -440,9 +440,9 @@ build_defs( int defCt, tDefList* pList )
                 fprintf( pfTrace, "Scheme eval for arg %d:\n\t`%s'\n",
                          pCurMacro->sibIndex - defCt, pList->pzExpr );
             }
-            res = ag_eval( pList->pzExpr );
 
-            if (gh_string_p( res )) {
+            res = ag_eval( pList->pzExpr );
+            if (AG_SCM_STRING_P( res )) {
                 AGDUPSTR( pList->de.val.pzText, ag_scm2zchars(res, "eval res"),
                           "dup eval res" );
             }
@@ -472,6 +472,8 @@ build_defs( int defCt, tDefList* pList )
  *  what:    Define a user AutoGen macro
  *  cindex:  define macro
  *  handler_proc:
+ *  load_proc:
+ *  unload-proc:
  *
  *  desc:
  *
@@ -518,6 +520,7 @@ build_defs( int defCt, tDefList* pList )
 /*=macfunc ENDDEF
  *
  *  what:   Ends a macro definition.
+ *  in-context:
  *
  *  desc:
  *    This macro ends the @code{DEFINE} function template block.
@@ -644,9 +647,10 @@ mFunc_Invoke( tTemplate* pT, tMacro* pMac )
      */
     macName = eval( pT->pzTemplText + pMac->ozName );
 
-    pInv = findTemplate( ag_scm2zchars( macName, "macro name" ));
+    pzText = ag_scm2zchars( macName, "macro name" );
+    pInv = findTemplate( pzText );
     if (pInv == NULL) {
-        pzText = aprf( zNoResolution, ag_scm2zchars( macName, "macro name" ));
+        pzText = aprf( zNoResolution, pzText );
         AG_ABEND_IN( pT, pMac, pzText );
         /* NOTREACHED */
     }
@@ -669,6 +673,13 @@ mLoad_Debug( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 }
 
 
+void
+mUnload_Define( tMacro* pMac )
+{
+    unloadTemplate( (tTemplate*)(pMac->funcPrivate) );
+}
+
+
 tMacro*
 mLoad_Define( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 {
