@@ -1,7 +1,7 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
  * Prototypes for autoopts
- * Generated Sat Oct  8 11:13:46 PDT 2005
+ * Generated Sun Jan  8 19:27:22 PST 2006
  */
 #ifndef AUTOOPTS_PROTO_H_GUARD
 #define AUTOOPTS_PROTO_H_GUARD
@@ -21,7 +21,7 @@ LOCAL tSuccess
 longOptionFind( tOptions* pOpts, char* pzOptName, tOptState* pOptState );
 
 LOCAL tSuccess
-shortOptionFind( tOptions* pOpts, tUC optValue, tOptState* pOptState );
+shortOptionFind( tOptions* pOpts, tAoUC optValue, tOptState* pOptState );
 
 LOCAL tSuccess
 doImmediateOpts( tOptions* pOpts );
